@@ -14,8 +14,8 @@ pub fn add_2()
 pub fn add_twice()
 {
     println!("--my_project::add_twice()--");
-    add_1();
-    add_1();
+    test0::add_1();
+    test0::add_1();
     println!("----");
 }
 
